@@ -102,8 +102,10 @@ class LsaTemplate_NT6(PackageTemplate):
 				
 			elif WindowsBuild.WIN_10_1809.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_11.value:
 				template = templates['nt6']['x64']['6']
-			else:
+			elif WindowsMinBuild.WIN_11.value <= sysinfo.buildnumber < WindowsBuild.WIN_11_24H2.value:
 				template = templates['nt6']['x64']['8']
+			else:
+				template = templates['nt6']['x64']['9']
 			
 		else:
 			raise Exception('Missing LSA decrpytor template for Architecture: %s , Build number %s' % (sysinfo.architecture, sysinfo.buildnumber))
@@ -544,4 +546,4 @@ templates = {
 			'7' : LSA_x86_7(),
 		}
 	}
-}
\ No newline at end of file
+}
