@@ -14,7 +14,7 @@ class SspCredential:
 		self.username = None
 		self.domainname = None
 		self.password = None
-		self.password_raw = None
+		self.password_raw = b''
 		self.luid = None
 	
 	def to_dict(self):
@@ -57,13 +57,13 @@ class SspDecryptor(PackageDecryptor):
 		c.domainname = await ssp_entry.credentials.UserName.read_string(self.reader)
 		if ssp_entry.credentials.Password.Length != 0:
 			if c.username.endswith('$') is True or c.domainname.endswith('$') is True:
-				enc_data = await ssp_entry.credentials.Password.read_data(self.reader)
-				c.password, c.password_raw = self.decrypt_password(enc_data, bytes_expected=True)
+				enc_data = await ssp_entry.credentials.Password.read_maxdata(self.reader)
+				c.password, c.password_raw = self.decrypt_password(enc_data, bytes_expected=True, segment_size=8)
 				if c.password is not None:
 					c.password = c.password.hex()
 			else:
-				enc_data = await ssp_entry.credentials.Password.read_data(self.reader)
-				c.password, c.password_raw = self.decrypt_password(enc_data)
+				enc_data = await ssp_entry.credentials.Password.read_maxdata(self.reader)
+				c.password, c.password_raw = self.decrypt_password(enc_data, segment_size=8)
 		
 		if c.username == '' and c.domainname == '' and c.password is None:
 			return
