@@ -1,11 +1,13 @@
 from pypykatz.commons.common import UniversalEncoder, hexdump
 import argparse
+import json
 import platform
 
 from pypykatz.dpapi.structures.blob import DPAPI_BLOB
 from pypykatz.dpapi.structures.credentialfile import CredentialFile
 from pypykatz.dpapi.structures.masterkeyfile import MasterKeyFile
 from pypykatz.dpapi.structures.vault import VAULT_VPOL
+from pypykatz.dpapi.finders.registry import RegFinder
 from winacl.dtyp.wcee.pvkfile import PVKFile
 
 
@@ -76,6 +78,12 @@ class DPAPICMDHelper:
 		prekey_nt.add_argument('nthash', help='NT hash of the user')
 		prekey_nt.add_argument('-o', '--out-file', help= 'Key candidates will be stored in this file. Easier to handle this way in the masterkeyfil command.')
 
+		prekey_sha1 = dpapi_prekey_subparsers.add_parser('sha1', help = 'Generate prekeys from SHA1 hash')
+		prekey_sha1.add_argument('sid', help='SID of the user')
+		prekey_sha1.add_argument('sha1hash', help='SHA1 hash of the user')
+		prekey_sha1.add_argument('-o', '--out-file', help= 'Key candidates will be stored in this file. Easier to handle this way in the masterkeyfil command.')
+
+
 		prekey_registry = dpapi_prekey_subparsers.add_parser('registry', help = 'Generate prekeys from registry secrets')
 		prekey_registry.add_argument('system', help='SYSTEM hive')
 		prekey_registry.add_argument('sam', help='SAM hive')
@@ -94,6 +102,8 @@ class DPAPICMDHelper:
 		dpapi_minidump_group.add_argument('minidumpfile', help='path to minidump file')
 		dpapi_minidump_group.add_argument('-o', '--out-file', help= 'Master and Backup keys will be stored in this file. Easier to handle in other commands.')
 
+		dpapi_preferredkey_group = dpapi_subparsers.add_parser('preferredkey', help='Get preferred masterkey GUID')
+		dpapi_preferredkey_group.add_argument('preferredkeyfile', help='path to preferred masterkey file')
 
 		dpapi_masterkey_group = dpapi_subparsers.add_parser('masterkey', help='Decrypt masterkey file')
 		dpapi_masterkey_group.add_argument('masterkeyfile', help='path to masterkey file')
@@ -132,6 +142,7 @@ class DPAPICMDHelper:
 		dpapi_chrome_group.add_argument('localstate', help='Local State file')
 		dpapi_chrome_group.add_argument('--logindata', help='Login Data file')
 		dpapi_chrome_group.add_argument('--cookies', help='Cookies file')
+		dpapi_chrome_group.add_argument('--json', action='store_true', help='Print in JSON format')
 
 		dpapi_wifi_group = dpapi_subparsers.add_parser('wifi', help='Decrypt Windows WIFI config file')
 		dpapi_wifi_group.add_argument('mkf', help= 'Keyfile generated by the masterkey -o command.')
@@ -145,6 +156,12 @@ class DPAPICMDHelper:
 		dpapi_cloudapkd_group.add_argument('mkf', help= 'Keyfile generated by the masterkey -o command.')
 		dpapi_cloudapkd_group.add_argument('keyvalue', help='KeyValue string obtained from PRT')
 
+		dpapi_winhellopin_group = dpapi_subparsers.add_parser('winhellopin', help='Get winhello hash')
+		dpapi_winhellopin_group.add_argument('mkd', help= 'Directory path for all machine masterkeys. Usually: C:\\System32\\Microsoft\\Protect\\S-1-5-18\\User')
+		dpapi_winhellopin_group.add_argument('regdir', help= 'Directory path for all registry hives. Usually: C:\\System32\\config\\. SAM, SYSTEM, SECURITY hives needed')
+		dpapi_winhellopin_group.add_argument('ngcdir', help= 'Directory path of NGC folder. Usually: C:\\Windows\\ServiceProfiles\\LocalService\\AppData\\Local\\Microsoft\\Ngc\\')
+		dpapi_winhellopin_group.add_argument('cryptokeys', help= 'Directory path of cryptokeys folder. Usually: C:\\Windows\\ServiceProfiles\\LocalService\\AppData\\Roaming\\Microsoft\\Crypto\\Keys\\')
+
 
 	def execute(self, args):
 		if len(self.keywords) > 0 and args.command in self.keywords:
@@ -177,13 +194,18 @@ class DPAPICMDHelper:
 					pw = getpass.getpass()
 
 				dpapi.get_prekeys_from_password(args.sid, password = pw)
-			
+
 			elif args.prekey_command == 'nt':
 				if args.nthash is None or args.sid is None:
 					raise Exception('NT hash and SID must be specified for generating prekey in this mode')
 
-				dpapi.get_prekeys_from_password(args.sid, nt_hash = args.nthash)
+				dpapi.get_prekeys_from_password(args.sid, nt_hash=args.nthash)
 
+			elif args.prekey_command == 'sha1':
+				if args.sha1hash is None or args.sid is None:
+					raise Exception('SHA1 hash and SID must be specified for generating prekey in this mode')
+
+				dpapi.get_prekeys_from_password(args.sid, sha1_hash=args.sha1hash)
 
 			dpapi.dump_pre_keys(args.out_file)
 
@@ -199,6 +221,8 @@ class DPAPICMDHelper:
 			else:
 				dpapi.dump_pre_keys()
 
+		elif args.dapi_module == 'preferredkey':
+			dpapi.dump_preferred_masterkey_guid(args.preferredkeyfile)
 
 		elif args.dapi_module == 'masterkey':
 			if args.prekey is None:
@@ -293,15 +317,33 @@ class DPAPICMDHelper:
 			
 			res = dpapi.decrypt_all_chrome(db_paths, throw=False)
 			for file_path, url, user, password in res['logins']:
-				print('file: %s user: %s pass: %s url: %s' % (file_path, user, password, url))
+				if args.json:
+					print(json.dumps(dict(type='login', file=file_path, url=url, user=user, password=password.decode()), cls=UniversalEncoder))
+				else:
+					print('file: %s user: %s pass: %s url: %s' % (file_path, user, password, url))
 			for file_path, host_key, name, path, value in res['cookies']:
-				print('file: %s host_key: %s name: %s path: %s value: %s' % (file_path, host_key, name, path, value))
+				if args.json:
+					print(json.dumps(dict(type='cookie', file=file_path, domain=host_key, name=name, path=path, value=value.decode()), cls=UniversalEncoder))
+				else:
+					print('file: %s host_key: %s name: %s path: %s value: %s' % (file_path, host_key, name, path, value))
 
 		elif args.dapi_module == 'wifi':
 			dpapi.load_masterkeys(args.mkf)
 			wificonfig_enc = DPAPI.parse_wifi_config_file(args.wifixml)
 			wificonfig = dpapi.decrypt_wifi_config_file_inner(wificonfig_enc)
 			print('%s : %s' % (wificonfig['name'], wificonfig['key']))
+		
+		elif args.dapi_module == 'winhellopin':
+			hives = RegFinder.from_dir(args.regdir)
+			dpapi.get_prekeys_form_registry_files(hives['SYSTEM'], hives['SECURITY'], hives['SAM'])
+			dpapi.decrypt_masterkey_directory(args.mkd)
+			results = dpapi.winhello_pin_hash_offline(args.ngcdir, args.cryptokeys)
+			if len(results) == 0:
+				print('No results!')
+				return
+			
+			for h in results:
+				print(h)
 
 		elif args.dapi_module == 'describe':
 			def read_file_or_hex(x):
@@ -416,4 +458,4 @@ class DPAPICMDHelper:
 
 		elif args.livedpapicommand == 'wifi':
 			for wificonfig in dpapi.decrypt_wifi_live():
-				print('%s : %s' % (wificonfig['name'], wificonfig['key']))
\ No newline at end of file
+				print('%s : %s' % (wificonfig['name'], wificonfig['key']))
