@@ -116,9 +116,12 @@ class LsaTemplate_NT6(PackageTemplate):
 			elif WindowsBuild.WIN_10_1809.value <= sysinfo.buildnumber < WindowsMinBuild.WIN_11.value:
 				logger.debug('using x64 - 6')
 				template = templates['nt6']['x64']['6']
-			else:
+			elif WindowsMinBuild.WIN_11.value <= sysinfo.buildnumber < WindowsBuild.WIN_11_24H2.value:
 				logger.debug('using x64 - 8')
 				template = templates['nt6']['x64']['8']
+			else:
+				logger.debug('using x64 - 9')
+				template = templates['nt6']['x64']['9']
 			
 		else:
 			raise Exception('Missing LSA decrpytor template for Architecture: %s , Build number %s' % (sysinfo.architecture, sysinfo.buildnumber))
@@ -468,4 +471,4 @@ templates = {
 			'7' : LSA_x86_7(),
 		}
 	}
-}
\ No newline at end of file
+}
