@@ -4,11 +4,8 @@
 #  Tamas Jos (@skelsec)
 #
 
-import io
-import logging
-from minidump.win_datatypes import *
-from pypykatz.commons.common import *
-from .package_commons import *
+
+from pypykatz.commons.common import KatzSystemArchitecture, WindowsMinBuild
 from pypykatz.lsadecryptor.lsa_template_nt5 import LsaTemplate_NT5
 from pypykatz.lsadecryptor.lsa_template_nt6 import LsaTemplate_NT6
 
