@@ -31,10 +31,14 @@ class SspTemplate(PackageTemplate):
 				template.signature = b'\xc7\x47\x24\x43\x72\x64\x41\x48\x89\x47\x78\xff\x15'
 				template.first_entry_offset = 20
 				
-			elif sysinfo.buildnumber >= WindowsBuild.WIN_10_1507.value:
+			elif WindowsBuild.WIN_10_1507.value <= sysinfo.buildnumber < WindowsBuild.WIN_11_2022.value:
 				template.signature = b'\x24\x43\x72\x64\x41\xff\x15'
 				template.first_entry_offset = 14
 			
+			elif sysinfo.buildnumber > WindowsBuild.WIN_11_2022.value:
+				template.signature = b'\x24\x43\x72\x64\x41\x48\xff\x15'
+				template.first_entry_offset = 20
+
 			else:
 				#currently this doesnt make sense, but keeping it here for future use
 				raise Exception('Could not identify template! Architecture: %s sysinfo.buildnumber: %s' % (sysinfo.architecture, sysinfo.buildnumber))
@@ -66,4 +70,4 @@ class KIWI_SSP_CREDENTIAL_LIST_ENTRY:
 		self.unk1 = ULONG(reader).value
 		self.unk2 = ULONG(reader).value
 		reader.align()
-		self.credentials = KIWI_GENERIC_PRIMARY_CREDENTIAL(reader)
\ No newline at end of file
+		self.credentials = KIWI_GENERIC_PRIMARY_CREDENTIAL(reader)
