@@ -46,7 +46,7 @@ class LSASecret:
 			lss.process_secret()
 			
 		elif kn.startswith('$MACHINE.ACC'):
-			lss = LSASecretMachineAccount(kn, raw_secret, history)
+			lss = LSASecretMachineAccount(kn, raw_secret, history, username=system_hive.machinename)
 			lss.process_secret()
 		
 		else:
@@ -104,11 +104,13 @@ class LSASecretDefaultPassword(LSASecret):
 	def __init__(self, key_name, raw_secret, history):
 		LSASecret.__init__(self, key_name, raw_secret, history)
 		self.username = None
+		self.domain = None
 		self.secret = None
 		
 	def process_secret(self):
 		try:
 			self.secret = self.raw_secret.decode('utf-16-le')
+			self.secret = self.secret.replace('\x00', '')
 		except:
 			pass
 		else:
@@ -125,6 +127,7 @@ class LSASecretDefaultPassword(LSASecret):
 		t['key_name'] = self.key_name
 		t['history'] = self.history
 		t['username'] = self.username
+		t['domain'] = self.domain
 		t['secret'] = self.secret
 		return t
 		
@@ -153,12 +156,13 @@ class LSASecretASPNET(LSASecret):
 		return t
 
 class LSASecretMachineAccount(LSASecret):
-	def __init__(self, key_name, raw_secret, history):
+	def __init__(self, key_name, raw_secret, history, username = None):
 		LSASecret.__init__(self, key_name, raw_secret, history)
-		self.username = None
+		self.username = username
 		self.secret = None
 		self.kerberos_password = None
-	
+		self.raw_secret = raw_secret
+
 	def process_secret(self):
 		#only the NT hash is calculated here
 		ctx = MD4(self.raw_secret)#hashlib.new('md4')
@@ -179,7 +183,7 @@ class LSASecretMachineAccount(LSASecret):
 		return t
 		
 	def __str__(self):
-		return '=== LSA Machine account password ===\r\nHistory: %s\r\nNT: %s\r\nPassword(hex): %s\r\nKerberos password(hex): %s' % (self.history, self.secret.hex(), self.raw_secret.hex(), self.kerberos_password.hex())
+		return '=== LSA Machine account password ===\r\nHistory: %s\r\nUsername: %s\r\nNT: %s\r\nPassword(hex): %s\r\nKerberos password(hex): %s' % (self.history, self.username, self.secret.hex(), self.raw_secret.hex(), self.kerberos_password.hex())
 	
 		
 class LSASecretDPAPI(LSASecret):
