@@ -22,6 +22,7 @@ class SYSTEM:
 		self.hive = system_hive
 		self.currentcontrol = None
 		self.bootkey = None
+		self.machinename = None
 		
 	def get_currentcontrol(self):
 		logger.debug('[SYSTEM] determining current control set')
@@ -56,6 +57,7 @@ class SYSTEM:
 	def get_secrets(self):
 		self.get_currentcontrol()
 		self.get_bootkey()
+		self.get_machine_name()
 
 	def get_service_user(self, service_name):
 		if self.currentcontrol is None:
@@ -63,9 +65,33 @@ class SYSTEM:
 		
 		try:
 			key = '%s\\Services\\%s\\ObjectName' % (self.currentcontrol, service_name)
-			return self.hive.get_value(key)[1].decode('utf-16-le')
+			val = self.hive.get_value(key)[1]
+			val = val.decode('utf-16-le')
+			val = val.replace('\x00', '')
+			return val
 		except:
 			return None
+	
+	def get_machine_name(self):
+		if self.currentcontrol is None:
+			self.get_currentcontrol()
+		
+		try:
+			if self.machinename is not None:
+				return self.machinename
+			
+			key = '%s\\Control\\ComputerName\\ComputerName\\ComputerName' % self.currentcontrol
+			val = self.hive.get_value(key)
+			if isinstance(val[1], bytes):
+				self.machinename = val[1].decode('utf-16-le')
+			else:
+				self.machinename = val[1]
+			if self.machinename is not None:
+				self.machinename = self.machinename.replace('\x00', '')
+			return self.machinename
+		except Exception as e:
+			print('[SYSTEM] get_machine_name error: %s' % e)
+			return None
 
 	def to_dict(self):
 		t = {}
